@@ -12,7 +12,6 @@
 #' @importFrom utils .DollarNames
 #' @export
 .DollarNames.nn_module <- function(x, pattern = "") {
-  
   pars <- names(x[[".__enclos_env__"]][["private"]][["parameters_"]])
   bufs <- names(x[[".__enclos_env__"]][["private"]][["buffers_"]])
   mods <- names(x[[".__enclos_env__"]][["private"]][["modules_"]])
@@ -30,17 +29,18 @@ help_formals_handler.torch_tensor <- function(topic, source, ...) {
 }
 
 help_handler <- function(type, topic, source, ...) {
-  if (type == "completion")
+  if (type == "completion") {
     help_handler_completion(topic, source, ...)
-  else if (type == "parameter")
+  } else if (type == "parameter") {
     help_handler_parameter(topic, source, ...)
-  else
+  } else {
     NULL
+  }
 }
 
 get_tensor_method_arguments <- function(topic) {
   tryCatch(
-    rlang::fn_fmls_names(parent.env(Tensor)[[topic]])[-c(1,2)],
+    rlang::fn_fmls_names(parent.env(Tensor)[[topic]])[-c(1, 2)],
     error = function(e) {
       NULL
     }
@@ -51,7 +51,7 @@ help_handler_completion <- function(topic, source, ...) {
   signature <- get_tensor_method_arguments(topic)
   signature <- paste0(signature, collapse = ", ")
   signature <- paste0(topic, "(", signature, ")")
-  
+
   list(title = topic, signature = signature)
 }
 
@@ -59,4 +59,4 @@ help_handler_parameter <- function(topic, source, ...) {
   list(
     args = get_tensor_method_arguments(topic)
   )
-}
\ No newline at end of file
+}
