@@ -30,8 +30,7 @@ make_load_symbols <- function(decls) {
 
 decls <- readr::read_lines(
   "
-void _lantern_autograd_edge_list_delete (void* x)
-void _lantern_autograd_edge_delete (void* x)
+char* _lantern_Tensor_data_ptr_byte (void *self)
 "
 )
 
